[coreboot-gerrit] Change in coreboot[master]: vpd: Add support for reading BD addreses from the VPD

Matthias Kaehlcke (Code Review) gerrit at coreboot.org
Sat Sep 22 00:43:24 CEST 2018


Matthias Kaehlcke has uploaded this change for review. ( https://review.coreboot.org/28711


Change subject: vpd: Add support for reading BD addreses from the VPD
......................................................................

vpd: Add support for reading BD addreses from the VPD

Also scan the VPD for Bluetooth device addresses (BD_ADDR). Add them to
the tables after Ethernet and WiFi MACs to avoid mismatches on existing
systems that may have 'bluetooth_macX' set.

BUG=b:113114217

Change-Id: Ib290fba2504f6ed80c3a95e24627ae5922e608af
Signed-off-by: Matthias Kaehlcke <mka at chromium.org>
---
M src/vendorcode/google/chromeos/vpd_mac.c
1 file changed, 5 insertions(+), 3 deletions(-)



  git pull ssh://review.coreboot.org:29418/coreboot refs/changes/11/28711/1

diff --git a/src/vendorcode/google/chromeos/vpd_mac.c b/src/vendorcode/google/chromeos/vpd_mac.c
index e3ef04b..08ca58c 100644
--- a/src/vendorcode/google/chromeos/vpd_mac.c
+++ b/src/vendorcode/google/chromeos/vpd_mac.c
@@ -59,10 +59,12 @@
 void lb_table_add_macs_from_vpd(struct lb_header *header)
 {
 	/*
 	 * Mac addresses in the VPD can be stored in two groups, for ethernet
 	 * and WiFi, with keys 'ethernet_macX and wifi_macX.
 	 */
-	const char *mac_addr_key_bases[] = {"ethernet_mac0", "wifi_mac0"};
+	const char *mac_addr_key_bases[] = {"ethernet_mac0", "wifi_mac0",
+					    "bluetooth_mac0"};
 	char mac_addr_key[20]; /* large enough for either key */
 	char mac_addr_str[13]; /* 12 symbols and the trailing zero. */
 	int i, count;
@@ -59,10 +59,12 @@
 {
 	/*
-	 * Mac addresses in the VPD can be stored in two groups, for ethernet
-	 * and WiFi, with keys 'ethernet_macX and wifi_macX.
+	 * Mac addresses in the VPD can be stored in three groups, for
+	 * ethernet, WiFi and Bluetooh, with keys 'ethernet_macX,
+	 * wifi_macX and bluetooth_macX
 	 */

-- 
To view, visit https://review.coreboot.org/28711
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings

Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: Ib290fba2504f6ed80c3a95e24627ae5922e608af
Gerrit-Change-Number: 28711
Gerrit-PatchSet: 1
Gerrit-Owner: Matthias Kaehlcke <mka at chromium.org>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://mail.coreboot.org/pipermail/coreboot-gerrit/attachments/20180921/ae8322c6/attachment-0001.html>


More information about the coreboot-gerrit mailing list